@@ -1,5 +1,5 @@
 /**
- * @file print_defn.hpp
+ * @file bindings/python/print_defn.hpp
  * @author Ryan Curtin
  *
  * Print the definition of a Python parameter.
@@ -23,7 +23,7 @@ namespace python {
  * definition in the function declaration.
  */
 template<typename T>
-void PrintDefn(const util::ParamData& d,
+void PrintDefn(util::ParamData& d,
                const void* /* input */,
                void* /* output */)
 {
